@@ -25,7 +25,7 @@ class Applications(webdriver.Remote):
             seconds (int): the duration for the application to remain in the background
 
         Returns:
-            `WebDriver`
+            `appium.webdriver.webdriver.WebDriver`
         """
         data = {
             'seconds': seconds,
@@ -37,7 +37,7 @@ class Applications(webdriver.Remote):
         """Checks whether the application specified by `bundle_id` is installed on the device.
 
         Args:
-            bundle_id (int): the id of the application to query
+            bundle_id (str): the id of the application to query
 
         Returns:
             bool: `True` if app is installed
@@ -65,7 +65,7 @@ class Applications(webdriver.Remote):
                 on Android 6+ after the installation completes. False by default
 
         Returns:
-            `WebDriver`
+            `appium.webdriver.webdriver.WebDriver`
         """
         data = {
             'appPath': app_path,
@@ -88,7 +88,7 @@ class Applications(webdriver.Remote):
                 20000ms by default.
 
         Returns:
-            `WebDriver`
+            `appium.webdriver.webdriver.WebDriver`
         """
         data = {
             'appId': app_id,
@@ -102,7 +102,7 @@ class Applications(webdriver.Remote):
         """Start on the device the application specified in the desired capabilities.
 
         Returns:
-            `WebDriver`
+            `appium.webdriver.webdriver.WebDriver`
         """
         self.execute(Command.LAUNCH_APP)
         return self
@@ -112,7 +112,7 @@ class Applications(webdriver.Remote):
         the device.
 
         Returns:
-            `WebDriver`
+            `appium.webdriver.webdriver.WebDriver`
         """
         self.execute(Command.CLOSE_APP)
         return self
@@ -145,7 +145,7 @@ class Applications(webdriver.Remote):
             app_id (str): the application id to be activated
 
         Returns:
-            `WebDriver`
+            `appium.webdriver.webdriver.WebDriver`
         """
         data = {
             'appId': app_id,
@@ -177,9 +177,9 @@ class Applications(webdriver.Remote):
             string_file (str): the name of the string file to query
         """
         data = {}
-        if language != None:
+        if language is not None:
             data['language'] = language
-        if string_file != None:
+        if string_file is not None:
             data['stringFile'] = string_file
         return self.execute(Command.GET_APP_STRINGS, data)['value']
 
